summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlibraryhandle.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlibraryhandle.h')
-rw-r--r--kpovmodeler/pmlibraryhandle.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpovmodeler/pmlibraryhandle.h b/kpovmodeler/pmlibraryhandle.h
index 353b7b53..2263407e 100644
--- a/kpovmodeler/pmlibraryhandle.h
+++ b/kpovmodeler/pmlibraryhandle.h
@@ -180,11 +180,11 @@ public:
bool isSubLibrary( ) const { return m_subLibrary; }
/**
* Changes the parent library if this is a sub library
* @param parentPath The new parent path for this library
* @return PMLibraryHandle::Ok if successful or the reason for failure
*/
- PMLibraryHandle::PMResult changeParentLibrary( const TQString& parentPath );
+ PMLibraryHandle::PMResult changeParentLibrary( const TQString& tqparentPath );
private:
@@ -180,11 +180,11 @@ public:
bool isSubLibrary( ) const { return m_subLibrary; }
/**
- * Changes the parent library if this is a sub library
- * @param parentPath The new parent path for this library
+ * Changes the tqparent library if this is a sub library
+ * @param tqparentPath The new tqparent path for this library
* @return PMLibraryHandle::Ok if successful or the reason for failure
*/